@@ -3,7 +3,7 @@ import logging
 import re
 from logging.config import fileConfig
 from pathlib import Path
-
+from os import path
 import click
 from dotenv import find_dotenv, load_dotenv
 from tqdm import tqdm
@@ -11,14 +11,14 @@ from tqdm import tqdm
 import pandas as pd
 from src.models.utils import init_tokenizer, mask_tokens
 
-fileConfig('src/resources/log_config.ini')
+fileConfig(path.join(path.dirname(__file__), '../resources/log_config.ini'))
 logger = logging.getLogger(__name__)
 
 
 @click.command()
-@click.option('--input-filepath', type=click.Path())
-@click.option('--output-filepath', type=click.Path())
-@click.option('--model-name')
+@click.option('--input-filepath', type=click.Path(), required=True)
+@click.option('--output-filepath', type=click.Path(), required=True)
+@click.option('--model-name', required=True)
 def main(input_filepath, output_filepath, model_name):
     """ Runs data processing scripts to turn raw data from (../raw) into
         cleaned data ready to be analyzed (saved in ../processed).
