@@ -2,6 +2,7 @@ import gc
 import glob
 import logging
 import os
+from os import path
 from datetime import datetime
 from logging.config import fileConfig
 from pathlib import Path
@@ -22,7 +23,7 @@ import wandb
 from src.data.camembert_mlm_dataset import CamemBERTMaskedLMDataset
 from src.models.utils import count_parameters, init_tokenizer
 
-fileConfig('src/resources/log_config.ini')
+fileConfig(path.join(path.dirname(__file__), '../resources/log_config.ini'))
 logger = logging.getLogger(__name__)
 
 
@@ -79,13 +80,13 @@ def eval_model(model, dataloader, criterion, device):
 
 
 @click.command()
-@click.option('--learning-rate')
-@click.option('--batch-size')
-@click.option('--num-epochs')
-@click.option('--folds')
-@click.option('--model-name')
-@click.option('--model-path')
-@click.option('--dataset-path')
+@click.option('--learning-rate', required=True)
+@click.option('--batch-size', required=True)
+@click.option('--num-epochs', required=True)
+@click.option('--folds', required=True)
+@click.option('--model-name', required=True)
+@click.option('--model-path', required=True)
+@click.option('--dataset-path', required=True)
 def main(learning_rate,
          batch_size,
          num_epochs,
